/*
  This code shows how to write a SDL Text Class using a normal SDL window,
  it uses SDL_ttf as a text creator.
  It also uses the Unicode keyboard support from SDL.

  For any problem of installation or usage, please send me a message : 
	http://www.developpez.net/forums/private.php?do=newpm&u=78956

  Copyright (C) 2007 Beyler Jean Christophe

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
*/

#include <stdio.h>
#include <stdlib.h>
#include <SDL.h>
#include <SDL_framerate.h>

#include "CTexte.h"

static const int WIDTH=800;
static const int HEIGHT=600;
static STexte *txt = NULL;

void affiche(SDL_Surface *ecran)
{
    SDL_FillRect(ecran, NULL, 0);
   /* Affichage du texte */
   Texte_AffTexte(txt,  ecran);
}

int main(int argc, char **argv)
{
    SDL_Event event;
    SDL_Surface *ecran;
    int done = 0;
    FPSmanager manage;

    /* Initialisation */
    if(SDL_Init(SDL_INIT_VIDEO)!=0) {
	   fprintf(stderr, "Probleme pour initialiser SDL: %s\n", SDL_GetError());
	   return EXIT_FAILURE;
    }

    if(TTF_Init()==-1) {
        fprintf(stderr,"TTF_Init: %s\n", TTF_GetError());
        return EXIT_FAILURE;
    }

    /* Creation du texte */
    txt = Texte_Creer();

    if(txt == NULL) {
        fprintf(stderr, "Erreur lors de la creation de la structure STexte\n");
        return EXIT_FAILURE;
    }

    /* Mettre un titre à la fenetre */
    SDL_WM_SetCaption("Demo Texte", NULL);

    /* Initialise le FPSmanager */
    SDL_initFramerate(&manage);
    SDL_setFramerate(&manage, 60);

    /* Ouvrir une fenetre */
    ecran = SDL_SetVideoMode(WIDTH, HEIGHT, 32, SDL_HWSURFACE | SDL_DOUBLEBUF);
    if(ecran==NULL) {
      	done = 1;
    }

    /* Preparation du texte */
    if(!Texte_ChargerPolice(txt, "Fabian.ttf", 24, 255, 255, 255)) {
        fprintf(stderr, "Erreur chargement de la police, est-ce que vous en avez cherche un ?\n");
        return EXIT_FAILURE;
    }

    if(!Texte_AffTexte_PositionTexte(txt, ecran, "Test le texte", 0, 0)) {
        fprintf(stderr,"Erreur affichage du texte\n");
        return EXIT_FAILURE;
    }

    /* Gestion de l'unicode pour le clavier */
    SDL_EnableUNICODE(1);
    
    /* Ajout du repeat keys */
    SDL_EnableKeyRepeat(SDL_DEFAULT_REPEAT_DELAY, SDL_DEFAULT_REPEAT_INTERVAL);

    /* Boucle generale */
    while(!done)
    {
        /* Traiter les evenements */
        while(SDL_PollEvent(&event))
        {
            switch(event.type)
            {
                case SDL_QUIT:
                    done=1;
                    break;
                case SDL_KEYDOWN:
                    if(event.key.keysym.sym==SDLK_ESCAPE) {
                        done=1;
                    }

                    if(event.key.keysym.unicode != SDLK_BACKSPACE) {
                        /* Si on a un caractere normal */
                        if((event.key.keysym.unicode & 0xFF80) == 0) {
                            Texte_AjouteFin(txt,(event.key.keysym.unicode & 0x7F));
                        }
                    }
                    else {
                        Texte_EnleveFin(txt);
                    }
                    break;
                case SDL_MOUSEMOTION:
                    Texte_SetPosition(txt,event.motion.x, event.motion.y);
                    break;
                default:
                    break;
            }
        }

        affiche(ecran);
        SDL_framerateDelay(&manage);
        SDL_Flip(ecran);
    }

    Texte_Detruire(&txt);
    TTF_Quit();
    SDL_Quit();

    (void) argc;
    (void) argv;
    return EXIT_SUCCESS;
}
